
CPP_MESSAGE =
{
	OPEN_WINDOW			= "open_window",
	CLOSE_WINDOW		= "close_window",
	ADD_WINDOW			= "add_window",
	REFRESH_WINDOW		= "refresh_window",
	REMOVE_ALL_WINDOWS	= "remove_all_windows",
}

local CppMsgDispatcher = class("CppMsgDispatcher")

local s_instance = nil

-- Table m_messageContainer

-- 获取单例对象
function CppMsgDispatcher.getInstance()
	if (s_instance == nil) then
		s_instance = CppMsgDispatcher.new()
	end
	return s_instance
end

-- 构造函数
function CppMsgDispatcher:ctor()
	self.m_messageContainer = {}
end

-- 析构函数
function CppMsgDispatcher:dtor()
	self.m_messageContainer = nil
end

-- 注册消息 (消息类型，回调对象，回调函数)
function CppMsgDispatcher:register(messageType, object, func)
	local message = self.m_messageContainer[messageType]
	local info = {obj = object, fun = func}
	if (message) then
		table.insert(message, info)
	else
		self.m_messageContainer[messageType] = {info}
	end
end

-- 注销消息 (消息类型，回调对象，回调函数)
function CppMsgDispatcher:unregister(messageType, object, func)
	local message = self.m_messageContainer[messageType]
	if (message) then
		for i, info in ipairs(message) do
			if (info.obj == object and info.fun == func) then
				table.remove(message, i)
				break
			end
		end
	end
end

-- 注销所有消息
function CppMsgDispatcher:unregisterAll()
	self.m_messageContainer = {}
end

-- 分发消息 (消息类型，消息数据)
function CppMsgDispatcher:send( messageType, data )
	local message = self.m_messageContainer[messageType]
	if(message) then
	for i, info in ipairs(message) do
		info.fun(info.obj, messageType, data)
	end
end
end

function dispatchCppMessage( message, param )
	s_instance:send(message, param)
end

return CppMsgDispatcher