--[[
	网络消息管理器
]]

NMESSAGE =
{
	CS_ACHIEVEMENT		= 1901,
	SC_ACHIEVEMENT		= 11901,
	CS_MAIL				= 2200,
	SC_MAIL				= 12200,
}

JMESSAGE =
{
	SC_FeeRewardGetPrice	= 201, --领取累计充值奖励
	JSON_SIGN				= 300,
	JSON_REWARD				= 301,
}

local NetMsgManager = class("NetMsgManager")

local s_instance = nil

-- Table m_messageContainer

-- 获取单例对象
function NetMsgManager.getInstance()
	if (s_instance == nil) then
		s_instance = NetMsgManager.new()
	end
	return s_instance
end

-- 构造函数
function NetMsgManager:ctor()
	self.m_messageContainer = {}
end

-- 析构函数
function NetMsgManager:dtor()
	self.m_messageContainer = nil
end

-- 注册消息 (消息类型，回调对象，回调函数)
function NetMsgManager:register(messageType, object, func)
	local message = self.m_messageContainer[messageType]
	if (message) then
		if (message[object]) then
			table.insert(message[object], func)
		else
			message[object] = {func}
		end
	else
		message = {}
		message[object] = {func}
		self.m_messageContainer[messageType] = message
	end
end

-- 注销消息 (消息类型，回调对象，回调函数)
function NetMsgManager:unregister(messageType, object, func)
	local message = self.m_messageContainer[messageType]
	if (message) then
		if (message[object]) then
			for i, v in ipairs(message[object]) do
				if (v == func) then
					table.remove(message[object], i)
					break
				end
			end
		end
	end
end

-- 注销所有消息
function NetMsgManager:unregisterAll()
	self.m_messageContainer = {}
end

-- 分发消息 (消息类型，消息数据)
function NetMsgManager:send( messageType, data )
	sendMessageToServer(messageType, data)
end

function NetMsgManager:recieve( messageType, data )
	local message = self.m_messageContainer[messageType]
	if (message) then
		for object, funcList in pairs(message) do
			for i, func in ipairs(funcList) do
				func(object, messageType, data)
			end
		end
	end
end

-- 接收由C++底层传过来的网络消息
function recieveNetMessage( messageType, data )
	if (messageType < 1000) then
		data = json.decode(data)
	end
	s_instance:recieve(messageType, data)
end

-- 向服务器发送活动消息
function NetMsgManager:sendForJson( messageType, data )
	CPPInterfaceManager:GameNetRequest_SendJsonOperaitonMessageToServer(messageType, data)
end

return NetMsgManager