--[[
	界面管理器
	轻量级的管理。
	有一个根节点，是C++传进来了的容器层，每个场景传一次。需要考虑这个层移除导致需要清理lua的UI
]]

--UIID,常量
LUA_WINDOW_ACTIVITY_MAIN = 1
LUA_WINDOW_ACTIVITY_SUB_1 = 2

WINDOW_LUA_START	= 10000
WINDOW	= {}

require "ScrollViewBar"

VIEW_CLASS_NAMES = 
{
	"SignView",
	"ActivityView",
	"HuodongView",
	"MailView",
	"MainInterface",
	"FirstChargeView",
	"AchievementView",
	"ChargeRidderView",
	"ReturnDiamond",
	"SystemMessageBox",
	"ClientMessageBox",
    "ActivityDailyShare",
    "TimeLimit",
    "EveryDayRecharge",
    "BindPhone",
    "ChargeSkin",
    "MercenaryPackage",
    "ChargeCum",
    "ChargeFund",
}

SYSTEM_MESSAGE =
{
    NO_OPERATION = 1,               -- 没有操作
    SERVER_UNCATCH_ERROR = -1,      -- 服务器未捕获异常
    CANT_LOGIN = -100,              -- 无法登陆服务器
    WAIT_TO_LONG = -102,            -- 等待时间过长
    UNDER_ATTACK = -103,            -- 正在被攻击，不能上线
    BE_ATTACK = -104,               -- 被攻击
    BE_CHANGE = -105,               -- 被顶下线
    NET_BREAK = -106,               -- 网络断了
    BE_KICK = -107,                 -- 主动踢掉
    ROBOT_NO_LOGIN = -108,          -- 机器人 不能登陆
    BE_BANNED = -109,               -- 被封了
    SERVER_WILL_MAINTENANCE = -110, -- 服务器即将维护
    SERVER_MAINTENANCEING = -111,   -- 服务器维护中
    ACCOUNT_IS_NULL = -112,         -- 玩家不存在
    ENMEY_ONLINE = -200,
    TOKEN_ERROR = -301,             -- Token非法不能登陆
    TOKEN_WAIT_TO_LONG = -302,      -- 连接Token服务器超时不能登陆
    SERVER_ERROR = -1000,           -- 服务器错误
    LOAD_INITIAL = -1001,           -- 读场景数据错误
    SCENE_SWITCH = -1002,           -- 场景切换错误
    NET_CLOSE    = -1003,           -- 网断了
    PLAYER_CHEAT    = -2000,        -- 使用外挂，强行中断游戏
    SERVER_NO_RESPONCE = -10000,    -- DEBUG 断线
    RETURN_DIAMOND	= -401			-- 已领取返钻
}

Views = {}
ViewsNameById = {}
for i, name in ipairs(VIEW_CLASS_NAMES) do
    Views[name] = require(name)
	windowId = WINDOW_LUA_START + i
	WINDOW[name] = windowId
	ViewsNameById[windowId] = name
end

local WindowsManager = class("WindowsManager")

local s_instance = nil

-- Table m_views

function WindowsManager.getInstance()
	if (s_instance == nil) then
		s_instance = WindowsManager.new()
	end
	return s_instance
end

function WindowsManager:ctor()
	self.m_views = {}

	playername = CPPInterfaceManager:DataPlayer_GetPlayerName()
	print("playername = " .. playername)

	testStr = CPPInterfaceManager:LString_CreateStringByTranslate("loc_upgradehq_unlock")
	testStr = CPPInterfaceManager:LString_ReplaceOneIntValue(testStr, 30)
	print("testStr = " .. testStr)

	messageManager:register(MESSAGE.L_WINDOW_SHOW, self, self.showUIByMsg)
	messageManager:register(MESSAGE.L_WINDOW_REMOVE, self, self.removeUIByMsg)
	messageManager:register(MESSAGE.L_WINDOW_ADD, self, self.addUIByMsg)
	messageManager:register(MESSAGE.L_WINDOW_ACCEPT_KEY, self, self.setUIAcceptKey)

	cppMsgDispatcher:register(CPP_MESSAGE.OPEN_WINDOW, self, self.openWindow)
	cppMsgDispatcher:register(CPP_MESSAGE.CLOSE_WINDOW, self, self.closeWindow)
	cppMsgDispatcher:register(CPP_MESSAGE.ADD_WINDOW, self, self.addWindow)
	cppMsgDispatcher:register(CPP_MESSAGE.REFRESH_WINDOW, self, self.refreshWindow)
	cppMsgDispatcher:register(CPP_MESSAGE.REMOVE_ALL_WINDOWS, self, self.refreshWindow)
end

function WindowsManager:dtor()
	messageManager:unregister(MESSAGE.L_WINDOW_SHOW, self, self.showUIByMsg)
	messageManager:unregister(MESSAGE.L_WINDOW_REMOVE, self, self.removeUIByMsg)
	messageManager:unregister(MESSAGE.L_WINDOW_ADD, self, self.addUIByMsg)
	messageManager:unregister(MESSAGE.L_WINDOW_ACCEPT_KEY, self, self.setUIAcceptKey)

	cppMsgDispatcher:unregister(CPP_MESSAGE.OPEN_WINDOW, self, self.openWindow)
	cppMsgDispatcher:unregister(CPP_MESSAGE.CLOSE_WINDOW, self, self.closeWindow)
	cppMsgDispatcher:unregister(CPP_MESSAGE.ADD_WINDOW, self, self.addWindow)
	cppMsgDispatcher:unregister(CPP_MESSAGE.REFRESH_WINDOW, self, self.refreshWindow)
	cppMsgDispatcher:unregister(CPP_MESSAGE.REMOVE_ALL_WINDOWS, self, self.refreshWindow)

	self.m_views = nil
end

function DoLuaInitDefaultWindow()
	getShopData("dbSetShopInfo")
	DataRetDiamond.init()
	s_instance:addUI("MainInterface")
	s_instance.m_views.MainInterface:setIsAcceptBackKey(false)

end

--通过id来管理
function WindowsManager:showUI( name )
    print( "open UI "..name );
	local parent = openCppWindow(WINDOW[name])
	local view = Views[name]:create(parent)
	parent:addChild(view)
	view:ViewShowed( parent )
	self.m_views[name] = view
end


--通过id移除UI
function WindowsManager:removeUI( name )
    print( "remove UI "..name );
	local view = self.m_views[name]
	if (view) then
		view:dtor()
		closeCppWindow(WINDOW[name])
	end
	self.m_views[name] = nil
end

function WindowsManager:addUI( name )
	local parent = addCppWindow(WINDOW[name])
	local view = Views[name]:create()
	parent:addChild(view)
	view:ViewShowed( parent )
	self.m_views[name] = view
end

function WindowsManager:showUIByMsg( messageType, data )
	self:showUI(data.uiName)
end

function WindowsManager:addUIByMsg( messageType, data )
	self:addUI(data.uiName)
end

function WindowsManager:removeUIByMsg( messageType, data )
	self:removeUI(data.uiName)
end

function WindowsManager:setUIAcceptKey( messageType, data )
	local name = data.uiName
	local isAccept = data.isAccept
	self.m_views[name]:setIsAcceptBackKey(isAccept)
end

function showSystemMessageBox( type, data )
	s_instance:showUI("SystemMessageBox")
	s_instance.m_views.SystemMessageBox:refresh(type, data)
end

function showClientSystemMessageBox( type, para )
	if (type == SYSTEM_MESSAGE.ENMEY_ONLINE) then
		Util.ShowWarningMessage("loc_server_ememy_is_online")
	else
		s_instance:showUI("ClientMessageBox")
		s_instance.m_views.ClientMessageBox:refresh(type, para)
	end
end

function WindowsManager:openWindow( messageType, param )
	self:showUI(param)
end

function WindowsManager:closeWindow( messageType, param )
	self:removeUI(param)
end

function WindowsManager:addWindow( messageType, param )
	self:addUI(param)
end

function WindowsManager:refreshWindow( messageType, param )
	messageManager:sendL(param)
end

--当c++的ui管理器清理所有ui时的回调
function WindowsManager:removeWindowOnCppManagerClear( windowId )
	name = ViewsNameById[windowId]
	    print( "remove UI at cppWindowManagerClear"..name );
	local view = self.m_views[name]
	if (view) then
		view:dtor()
		--closeCppWindow(WINDOW[name])
	end
	self.m_views[name] = nil
end

function DoLuaReleaseWindow( windowId )
	s_instance:removeWindowOnCppManagerClear(windowId)
end

--移除所有UI
function WindowsManager:RemoveAllWindows( messageType, param )
	for name, view in pairs(s_instance.m_views) do
		view:dtor()
		closeCppWindow(WINDOW[name])
	end
	s_instance.m_views = {}
end

return WindowsManager
