--[[
	签到的数据模块
]]

SHOP_EVERYDAY_FIRST_CHARGE_ID	= 4

DataShop = {}

local s_itemData = nil
local s_monthCard = nil
local s_isLock = nil

function DataShop.init( allData )
	s_itemData = {}
	for i, item in ipairs(allData.items) do
		local data = {}
		data.id = item.id
		data.isCharged = item.isCharged
		table.insert(s_itemData, data)
	end
	s_monthCard = {endTime = tonumber(allData.endTime), lastTime = tonumber(allData.lastTime)}
	s_isLock = false
end

function DataShop.updateCharge( data )
	if (s_itemData == nil) then return end
	local item = DataShop.getItemByID(data.shopId)
	item.isCharged = true
	s_monthCard.endTime = tonumber(data.endTime)
end

function DataShop.updateMonthCard( data )
	if (s_itemData == nil) then return end
	s_monthCard.lastTime = tonumber(data.newRewardTime)
end

function DataShop.refreshDay()
	if (s_itemData == nil) then return end
    local item = DataShop.getItemByID(SHOP_EVERYDAY_FIRST_CHARGE_ID)
	item.isCharged = false
end

function DataShop.setLockStatus(isLock)
	s_isLock = isLock
end

function DataShop.getItemCount()
	return #s_itemData
end

function DataShop.getItem( index )
	return s_itemData[index]
end

function DataShop.getItemByID( id )
	for i, data in ipairs(s_itemData) do
		if (data.id == id) then
			return data, i
		end
	end
end

function DataShop.isFirstCharge()
	for i, data in ipairs(s_itemData) do
		if (data.isCharged) then
			return false
		end
	end
	return true
end

function DataShop.getMonthCardRemainDay()
	if (s_monthCard.endTime == 0) then return -1 end
    local curDay = Util.FormateTimeToDay(Util.GetServerTime())
    local endDay = Util.FormateTimeToDay(s_monthCard.endTime)
    return (endDay - curDay)
end

function DataShop.isMonthCardRewarded()
	local curDay = math.floor(Util.FormateTimeToDay(Util.GetServerTime()))
    local lastDay = math.floor(Util.FormateTimeToDay(s_monthCard.lastTime))
    return (curDay <= lastDay)
end

function DataShop.isShopRewarded( index )
	return (s_itemData[index].isCharged)
end

function DataShop.isLocked()
	return s_isLock
end

function dbSetShopInfo( allData )
	DB_SHOP = {}
	for i, item in ipairs(allData.items) do
		local data = {}
		data.name = item.name
		data.count = item.count
		data.price = item.price
		data.icon = item.icon
		data.month = item.month
		table.insert(DB_SHOP, data)
	end
	DataShop.init(allData)
end