local AchievementView = class("AchievementView", require("BaseView"))

local _super = AchievementView.super

local SROLLVIEW_CHILD_DISTANCE = 130

local FLAG_STAR_COUNT = 3

-- Table m_flagList
-- Number m_svHeight

local function createScrollView(x, y, size)
    local svSize = cc.size(size.width - 30, size.height - 20)
    local sv = ccui.ScrollView:create()
    sv:setDirection(2)
    sv:setBounceEnabled(false)
    sv:setAnchorPoint(cc.p(0.5, 0.5))
    sv:setPosition(x, y)
    sv:setContentSize(svSize)
    sv:setScrollBarEnabled(false)
    return sv
end

function AchievementView:ctor(t)
	_super.ctor(self, t, "ui_assembly", true)
    print("AchievementView:ctor")
    self:createBackground(VIEW_BACKGROUND_COLOR, false)
    self:initView()
    messageManager:register(MESSAGE.SC_ACHIEVEMENT, self, self.refresh)
end

function AchievementView:dtor()
    messageManager:unregister(MESSAGE.SC_ACHIEVEMENT, self, self.refresh)
    self.m_flagList = nil
    self.m_svHeight = nil
    _super.dtor(self)
    print("AchievementView:dtor")
end

function AchievementView:initView()
    local nodes = self.m_nodes
    local data = self.m_data

    if self.m_rootNode then
    	self.m_rootNode:setPosition(cc.p(winSizeHalf.width, winSizeHalf.height))
    end

    self.m_flagList = {}
    nodes.btnClose = self.m_rootNode:getNodeByName("quitButton")
    nodes.board = self.m_rootNode:getNodeByName("blueBoard")
    self.m_rootNode:getLabelByName("titleLabel"):setString(getStringInLang("loc_achievement_title"))

    local boardX, boardY = nodes.board:getPositionX(), nodes.board:getPositionY()
    local boardSize = nodes.board:getContentSize()
    data.rect = cc.rect(0, 0, boardSize.width, boardSize.height)

    nodes.scrollView = createScrollView(boardX, boardY, boardSize)
    self.m_svHeight = nodes.scrollView:getContentSize().height
    self.m_rootNode:getNodeByName("boardNode"):addChild(nodes.scrollView)

    local function closeSelf( sender )
        if (sender == nodes.btnClose) then
            self:closeWindow()
        end
    end

    setNEButtonCallBack(nodes.btnClose, NEBattleEvent.NEButtonEventTouchUpInside, closeSelf)
    -- 测试代码，假数据
    self:refresh("", {{}, {}, {}, {}})
end

local function createFlagNode( x, y, achieve )
    local flagNodes = {}
    local rootNode = neanim.NEAnimNode:createNodeFromFile("ani/ui_chengjiu_flag.ani")
    rootNode:setPosition(cc.p(x, y))
    flagNodes.root = rootNode
    flagNodes.nodeGain = rootNode:getNodeByName("gainNode")
    flagNodes.btnGain = rootNode:getNodeByName("gainButton")
    flagNodes.labName = rootNode:getLabelByName("nameLabel")
    flagNodes.animProcess = rootNode:getNodeByName("processAnim")
    flagNodes.labProcess = flagNodes.animProcess:getLabelByName("processLabel")
    flagNodes.imgPipe = flagNodes.animProcess:getNodeByName("pipeSprite")
    flagNodes.imgPipeBg = flagNodes.animProcess:getNodeByName("pipeBgSprite")
    flagNodes.labNum = rootNode:getLabelByName("numLabel")
    flagNodes.labDec = rootNode:getLabelByName("decLabel")
    flagNodes.labFinish = rootNode:getLabelByName("finishLabel")
    flagNodes.animStars = {}
    for i = 1, FLAG_STAR_COUNT do
        flagNodes.animStars[i] = rootNode:getNodeByName("starAnim0" .. i)
    end
    rootNode:getLabelByName("processTitle"):setString(getStringInLang("loc_achievement_process"))
    rootNode:getLabelByName("gainNode/buttonLabel"):setString(getStringInLang("loc_achievement_claim"))
    rootNode:getLabelByName("rewardTitle"):setString(getStringInLang("loc_achievement_reward"))
    flagNodes.labFinish:setVisible(false)
    flagNodes.nodeGain:setVisible(false)
    return flagNodes
end

local function refreshFlag( flagNodes, ctData, netData )
    flagNodes.labName:setString(getStringInLang(getAchievementName(ctData)))
    flagNodes.labNum:setString(tostring(getAchievementRewardNum(ctData)))
    -- local percent = 0
    -- local maxValue = 0
    -- local group = getAchievementGroup(ctData)
    -- local achieveStep = getAchievementProcessValue(group)

    -- if (group == 5010) then
    --     maxValue = getAchievementObject(ctData)
    -- else
    --     maxValue = getAchievementGoalValue(ctData)
    -- end
    -- percent = netData.curVaule / maxValue
    -- local processStr = netData.curVaule .. "/" .. maxValue
    -- local size = flagNodes.imgPipeBg:getContentSize()
    -- size.width = size.width * percent
    -- flagNodes.labProcess:setString(processStr)
    -- flagNodes.imgPipe:setContentSize(cc.size(size.width * percent, size.height))
    -- flagNodes.btnGain:setTag(netData.achievementId)
    -- local pipeBgWidth = flagNodes.imgPipeBg:getContentSize().width
    -- local processLabelWidth = flagNodes.labProcess:getContentSize().width
    -- if (processLabelWidth > (pipeBgWidth - 2)) then
    --     processLabel:setScale((pipeBgWidth - 2) / processLabelWidth)
    -- end
    -- for i, animStar in ipairs(flagNodes.animStars) do
    --     if (achieveStep >= i) then
    --         animStar:playAnimation("liang")
    --     else
    --         animStar:playAnimation("pingshi")
    --     end
    -- end
end

function AchievementView:refresh( messageType, data )
    for i, flagNode in ipairs(self.m_flagList) do
        flagNode.root:removeFromParent()
    end
    self.m_flagList = {}
    for i, achieve in ipairs(data) do
        local flagNodes = createFlagNode(75 + SROLLVIEW_CHILD_DISTANCE * (i - 1), self.m_svHeight / 2, achieve)
        self.m_nodes.scrollView:addChild(flagNodes.root, 0, i)
        -- local ctData = getAchievementByID(achieve.achievementId)
        -- refreshFlag(flagNodes, ctData, achieve)
        table.insert(self.m_flagList, flagNodes)
    end
    self.m_nodes.scrollView:setInnerContainerSize(cc.size(150 + SROLLVIEW_CHILD_DISTANCE * (#data - 1), self.m_svHeight))
end

function AchievementView:onViewTouchEnded(touch, event)
    local touchPoint = self.m_nodes.board:convertToNodeSpace(touch:getLocation())
    if (not cc.rectContainsPoint(self.m_data.rect, touchPoint)) then
        self:closeWindow()
    end
end

return AchievementView
