VIEW_BACKGROUND_COLOR   = cc.c4b(0, 0, 0, 150)
VIEW_BACKGROUND_NO_COLOR   = cc.c4b(0, 0, 0, 0)

local BaseView = class("BaseView", cc.Layer)

-- NEAnimNode m_rootNode    根节点
-- Table m_data             数据
-- Table m_nodes            节点
-- LayerColor m_bgLayer     背景层

function BaseView:ctor(uiName, isSwallow)
    print("BaseView:ctor")
    self:initBaseViewData()
    self:setTouchEvent(isSwallow)
    if( uiName == "")then
        self.m_rootNode = cc.Node:create();
    else
        self.m_rootNode = neanim.NEAnimNode:createNodeFromFile(uiName .. ".ani")
    end
    self:addChild(self.m_rootNode, 1)
end

function BaseView:dtor()
    print("BaseView:dtor")
    self.m_rootNode:removeFromParent()
    self.m_rootNode = nil
    self.m_data = nil
    self.m_nodes = nil
    self.m_bgLayer = nil
    self.m_isOutsideClose = nil
    self.isMove = nil
end

--初始化 数据 表
function BaseView:initBaseViewData()
    self.m_data = {}
    self.m_nodes = {}
    self.m_isOutsideClose = false
    self.isMove = false
    self.zOrder = 1
end

function BaseView:setNeedMask( parent, showMask )
    setWindowMask(parent, showMask)
end

function BaseView:setName( name )
    self.m_data.name = name
end

function BaseView:getName()
    return self.m_data.name
end

--[[
    触摸事件默认添加
]]
function BaseView:setTouchEvent(isSwallow)
    isSwallow = isSwallow or false
    self:setTouchEnabled(true)
    local function onTouchBegan(touch, event)
        -- local touchPoint = touch:getLocation()
        -- print("touchPoint" .. touchPoint.x, touchPoint.y)

        return self:onViewTouchBegan(touch, event)
    end

    local function onTouchMoved(touch, event)
        --local touchPoint = touch:getLocation()
        --local touchStart = touch:getStartLocation()
        --if( ( touchStart.x - touchPoint.x ) * ( touchStart.x - touchPoint.x ) + ( touchStart.y - touchPoint.y ) * ( touchStart.y - touchPoint.y ) > 10 ) then
            self.isMove = true
        --end
        self:onViewTouchMoved(touch, event)
    end

    local function onTouchEnded(touch, event)
        local touchPoint = touch:getLocation()
        print("touchPoint" .. touchPoint.x, touchPoint.y)
        if (self.m_isOutsideClose) then
            if (not self.isMove) then
                self:closeWindow(self.m_data.name)
                return
            end
        end
        self:onViewTouchEnded(touch, event)
        self.isMove = false
    end

    local function onTouchCancelled(touch, event)
        self:onViewTouchCancelled(touch, event)
    end

    local listener = cc.EventListenerTouchOneByOne:create()
    listener:registerScriptHandler(onTouchBegan, cc.Handler.EVENT_TOUCH_BEGAN)
    listener:registerScriptHandler(onTouchMoved, cc.Handler.EVENT_TOUCH_MOVED)
    listener:registerScriptHandler(onTouchEnded, cc.Handler.EVENT_TOUCH_ENDED)
    listener:registerScriptHandler(onTouchCancelled, cc.Handler.EVENT_TOUCH_CANCELLED)
    local eventDispatcher = self:getEventDispatcher()
    eventDispatcher:addEventListenerWithSceneGraphPriority(listener, self)

    listener:setSwallowTouches(isSwallow)
    self.m_data.eventListener = listener
end

function BaseView:createBackground( colorInfo, isOutsideClose )
    if (colorInfo) then
        self.m_bgLayer = cc.LayerColor:create(colorInfo)
        self:addChild(self.m_bgLayer, 0)
    end
    if (isOutsideClose) then
        self.m_isOutsideClose = isOutsideClose
    end
end

-- 子类去实现自己的touch事件
function BaseView:onViewTouchBegan(touch, event)
    return true
end

function BaseView:onViewTouchMoved(touch, event)

end

function BaseView:onViewTouchEnded(touch, event)
    -- body
end

function BaseView:onViewTouchCancelled(touch, event)
    -- body
end

function BaseView:openWindow(name)
    messageManager:sendL(MESSAGE.L_WINDOW_SHOW, {uiName = name})
end

function BaseView:addWindow(name)
    messageManager:sendL(MESSAGE.L_WINDOW_SHOW, {uiName = name})
end

function BaseView:closeWindow(name)
    messageManager:sendL(MESSAGE.L_WINDOW_REMOVE, {uiName = name})
end

function BaseView:createSubWindow(name)
    return Views[name]:create()
end

function BaseView:setIsAcceptBackKey(isAccept)
    setAcceptBackKey(self:getParent(), isAccept)
end

function BaseView:ViewShowed( parent )
    CPPInterfaceManager:WindowSetZOrderLayer( parent, self.zOrder)
end

function BaseView:setZOrderLayer( z )
    self.zOrder = z
end

return BaseView
