local FirstChargeView = class("FirstChargeView", require("BaseView"))

local _super = FirstChargeView.super

local NEButtonData = AppData.NEButtonData

function FirstChargeView:ctor(parent)
	_super.ctor(self, "ui_shouchong", true)
    print("FirstChargeView:ctor")
    self:setNeedMask(parent, true)
    self:createBackground(VIEW_BACKGROUND_NO_COLOR, true)
    self:setName("FirstChargeView")
    self:initView()
    messageManager:register(MESSAGE.SC_CHARGE, self, self.refresh)
    messageManager:register(MESSAGE.SC_CHARGE_TEST, self, self.refresh)
end

function FirstChargeView:dtor()
    messageManager:unregister(MESSAGE.SC_CHARGE, self, self.refresh)
    messageManager:unregister(MESSAGE.SC_CHARGE_TEST, self, self.refresh)
    _super.dtor(self)
    animManager:unusedSpriteframesFromPath("yasuo_shouchong_" .. Util.GetNationName(CPPInterfaceManager:DataPlayer_GetNation()))
    print("FirstChargeView:dtor")
end

function FirstChargeView:initView()
    local nodes = self.m_nodes
    local data = self.m_data

    if self.m_rootNode then
    	self.m_rootNode:setPosition(cc.p(winSize.width / 2 , winSize.height / 2))
    end

    local isRecharge = CPPInterfaceManager:DataPlayer_IsRecharge()
    nodes.bg = self.m_rootNode:getNodeByName("ditu")
    nodes.icon = self.m_rootNode:getNodeByName("ditu1")
    nodes.chargeAni = self.m_rootNode:getNodeByName("chargeAni")
    nodes.btnClose = self.m_rootNode:getNodeByName("closeButton")
    nodes.btnCharge = self.m_rootNode:getNodeByName("chargeButton")
    CPPInterfaceManager:NEButtonNode_SetTouchEnabled(nodes.btnCharge,not(isRecharge))
    nodes.chargeInfo = self.m_rootNode:getLabelByName("info")
    nodes.btnLabel = nodes.chargeAni:getLabelByName("buttonLabel")
    nodes.labTitle = self.m_rootNode:getLabelByName("title")
    nodes.labTips = self.m_rootNode:getLabelByName("tips")
    nodes.labName = self.m_rootNode:getLabelByName("name")
    nodes.labDesc = self.m_rootNode:getLabelByName("desc")

    local nation = CPPInterfaceManager:DataPlayer_GetNation()
    local nationName = Util.GetNationName(nation)
    local plistName = "yasuo_shouchong_" .. nationName
    animManager:useSpriteframesFromPath(plistName)

    if (nation == NATION_TYPE.NATION_TYPE_USA) then
        -- self.m_rootNode:useSkin("usa")
        nodes.labName:setString(getStringInLang("loc_first_charge_jinetes"))
        Util.SetSpriteFrame(nodes.bg, plistName .. "/info_s_jinetes_usa")
        Util.SetSpriteFrame(nodes.icon, "ui_usa/info_usaelite_jinetes")
    elseif (nation == NATION_TYPE.NATION_TYPE_GER) then
        -- self.m_rootNode:useSkin("deu")
        nodes.labName:setString(getStringInLang("loc_first_charge_savoia"))
        Util.SetSpriteFrame(nodes.bg, plistName .. "/info_s_savoia_deu")
        Util.SetSpriteFrame(nodes.icon, "ui_deu/info_deuelite_savoia")
    elseif (nation == NATION_TYPE.NATION_TYPE_SOV) then
        -- self.m_rootNode:useSkin("sov")
        nodes.labName:setString(getStringInLang("loc_first_charge_cossack"))
        Util.SetSpriteFrame(nodes.bg, plistName .. "/info_s_cossack_sov")
        Util.SetSpriteFrame(nodes.icon, "ui_sov/info_sovelite_cossack")
    elseif (nation == NATION_TYPE.NATION_TYPE_CHN) then
        -- self.m_rootNode:useSkin("chn")
        nodes.labName:setString(getStringInLang("loc_first_charge_chinese"))
        Util.SetSpriteFrame(nodes.bg, plistName .. "/info_s_nwcavalry_chn")
        Util.SetSpriteFrame(nodes.icon, "ui_chn/info_chnelite_nwcavalry")
    end

    if (isRecharge) then
        nodes.chargeAni:useSkin("F60")
    end

    local function closeSelf( sender )
        if (self.closeWindow and sender == nodes.btnClose) then
            self:closeWindow("FirstChargeView")
        end
    end

    local function chargeEvent( sender )
        if (sender == nodes.btnCharge) then
            messageManager:sendS(MESSAGE.CS_CHARGE, {shopID = 1})
            self:closeWindow("FirstChargeView")
        end
    end

    nodes.chargeInfo:setString(getStringInLang("loc_first_charge_rider_intro"))
    nodes.btnLabel:setString(getStringInLang("loc_first_charge_price_one"))
    nodes.labTitle:setString(getStringInLang("loc_first_charge_gift"))
    nodes.labTips:setString(getStringInLang("loc_first_charge_six_yuan"))
    nodes.labDesc:setString(getStringInLang("loc_first_charge_weekcard"))
    setNEButtonCallBack(nodes.btnClose, NEBattleEvent.NEButtonEventTouchUpInside, closeSelf)
    setNEButtonCallBack(nodes.btnCharge, NEBattleEvent.NEButtonEventTouchUpInside, chargeEvent)
end

function FirstChargeView:refresh( messageType, data )
    if (data.diamond > 0) then
        local function closeSelf()
            self:closeWindow("FirstChargeView")
        end
        --Util.ShowNormalMessage("loc_shop_up_content", data.diamond)
        --CPPInterfaceManager:DataPlayer_AddDiamond(data.diamond)
        --CPPInterfaceManager:UIEffect_FlyResourceIcon(self.m_rootNode, 0, 0, 11, data.diamond)
        performWithDelay(self.m_rootNode, closeSelf, 0.5)
        self:openWindow("ChargeRidderView")
    end
end

return FirstChargeView
