ACTIVITY_TYPE_SIGN  = 1
ACTIVITY_TYPE_DAILY_SHARE = 2
ACTIVITY_TYPE_TIME_LIMIT = 3
ACTIVITY_TYPE_EVERYDAY_RECHARGE = 4
ACTIVITY_TYPE_PHONE = 5
ACTIVITY_TYPE_CHARGE_SKIN = 6
ACTIVITY_TYPE_CHARGE_CUM = 7
ACTIVITY_TYPE_FUND = 8

HUODONG_TAB_ACTIVITY    = 1
HUODONG_TAB_NOTICE      = 2

local HuodongView = class("HuodongView", require("BaseView"))

local BUTTON_VIEW_WIDTH  = 124
local BUTTON_VIEW_HEIGHT = 224
local BUTTON_VIEW_OFFSET = 220
local BUTTON_VIEW_OFFSET_Y = 30
local BUTTON_HEIGHT = 60

local RIGHT_VIEW_WIDTH  = 292
local RIGHT_VIEW_HEIGHT = 208

local SIGN_ICON_DISTANCE = 38

local _super = HuodongView.super

local NEButtonData = AppData.NEButtonData

local cumBtn = 0

local m_scroollViewOffset = nil


local function createRightScrollView( parent )
    local sv = ccui.ScrollView:create()
    sv:setDirection(kCCScrollViewDirectionVertical)
    sv:setAnchorPoint(cc.p(0, 1))
    sv:setScrollBarPositionFromCornerForVertical(cc.p(5, 0))
    -- sv:setVisible(false)
    parent:addChild(sv)
    return sv
end

local function insertIntoRightScrollview( self, sv, parentview, viewName )
    local oldView = sv:getChildByTag(0)
    if (oldView) then
        oldView:dtor()
    end
    sv:removeAllChildren()
    parentview:removeChildByTag(0)
    
    local view = self:createSubWindow(viewName, 1)
    local btmSize = view:getContentSize()
    local height = math.max(RIGHT_VIEW_HEIGHT, btmSize.height)
    view:setPosition(0, height)
    sv:addChild(view, 0, 0)
    self.m_curView = view

    sv:setContentSize(cc.size(btmSize.width, RIGHT_VIEW_HEIGHT))
    sv:setInnerContainerSize(cc.size(btmSize.width, height))
    sv:setScrollBarEnabled(btmSize.height > RIGHT_VIEW_HEIGHT)
end

local function insertWithoutScrollview( self, sv, parentview, viewName) 
    local oldView = parentview:getChildByTag(0)
    if (oldView) then
        oldView:dtor()
    end
    sv:removeAllChildren()
    parentview:removeChildByTag(0)

    local view = self:createSubWindow(viewName, 1)
    view:setPosition(0, 0)    
    parentview:addChild(view, 0, 0)    
    self.m_curView = view
end

function HuodongView:ctor(parent)
	_super.ctor(self, "ui_huodong", true)
    print("HuodongView:ctor")
    self:createBackground(VIEW_BACKGROUND_NO_COLOR, true)
    self:setName("HuodongView")
    self:setNeedMask(parent, true)
    self:initView()
    messageManager:register(MESSAGE.JSON_TIMELIMIT, self, self.refreshTimeLimit)
    messageManager:register(MESSAGE.JSON_CHARGE_SKIN_Receive, self, self.refreshTimeLimit)
    messageManager:register(MESSAGE.JSON_SIGN, self, self.refreshSing)
    messageManager:register(MESSAGE.JSON_REWARD, self, self.refreshSing)
    messageManager:register(EVENT.REFRESH_VIEW, self, self.refreshTimeLimit)
    messageManager:register(EVENT.SHARE_BUTTON_HAVETAKE, self, self.refreshWX)
    messageManager:register(MESSAGE.JSON_EVERYDAYRECHARGE_REWARD, self, self.refreshEveryDay)
    messageManager:register(MESSAGE.JSON_EVERYDAYRECHARGE, self, self.refreshEveryDay)
    messageManager:register(EVENT.REFRESH_EVERYDAY_VIEW, self, self.refreshEveryDay)
    messageManager:register(MESSAGE.JSON_CHARGE_CUM_Get, self, self.refreshCumCharge)
    messageManager:register(MESSAGE.JSON_CHARGE_FUND_Get, self, self.refreshEveryDay)
end

function HuodongView:dtor()
    self.m_isScrolling = nil
    if (self.m_curView) then
        self.m_curView:dtor()
        self.m_curView = nil
    end
    _super.dtor(self)
    print("HuodongView:dtor")
    messageManager:unregister(MESSAGE.JSON_TIMELIMIT, self, self.refreshTimeLimit)
    messageManager:unregister(MESSAGE.JSON_CHARGE_SKIN_Receive, self, self.refreshTimeLimit)
    messageManager:unregister(MESSAGE.JSON_SIGN, self, self.refreshSing)
    messageManager:unregister(MESSAGE.JSON_REWARD, self, self.refreshSing)
    messageManager:unregister(EVENT.REFRESH_VIEW, self, self.refreshTimeLimit)
    messageManager:unregister(EVENT.SHARE_BUTTON_HAVETAKE, self, self.refreshWX)
    messageManager:unregister(MESSAGE.JSON_EVERYDAYRECHARGE_REWARD, self, self.refreshEveryDay)
    messageManager:unregister(MESSAGE.JSON_EVERYDAYRECHARGE, self, self.refreshEveryDay)
    messageManager:unregister(EVENT.REFRESH_EVERYDAY_VIEW, self, self.refreshEveryDay)
    messageManager:unregister(MESSAGE.JSON_CHARGE_CUM_Get, self, self.refreshCumCharge)
    messageManager:unregister(MESSAGE.JSON_CHARGE_FUND_Get, self, self.refreshEveryDay)
end

function HuodongView:initView()
    local nodes = self.m_nodes
    local data = self.m_data
    self.m_isScrolling = false
    if self.m_rootNode then
    	self.m_rootNode:setPosition(cc.p(winSizeHalf.width, winSizeHalf.height))
    end

    nodes.btnClose = self.m_rootNode:getNodeByName("closeButton")
    nodes.btnBGClose = self.m_rootNode:getNodeByName("bg")
    -- nodes.btnActivity = self.m_rootNode:getNodeByName("labelButton1")
    -- nodes.btnNotice = self.m_rootNode:getNodeByName("labelButton2")
    -- self.m_rootNode:getLabelByName("labelNode2/wenzi"):setString("游戏公告")

    -- data.tabIndex = 0
    data.actIndex = 0
    data.notIndex = 0
    
    
	local function onTabBtnTouchDown( sender )
		print("touch down")
		sender:getParent():playAnimation("Push")	
	end

	local function onTabBtnTouchUpOutside( sender )
		print("touch up out")
		sender:getParent():playAnimation("pingshi")
	end

	local function onTabBtnTouchUpInside( sender )
		print("touch up inside")
		sender:getParent():playAnimation("Release")
		self:switchTab(sender)
	end

    local function closeSelf( sender )
    	print("close self")
        if sender == nodes.btnClose then
            self:closeWindow("HuodongView")
        end
        if sender == nodes.btnBGClose then
            self:closeWindow("HuodongView")
        end
    end

    local function scrollEnd( sender, eventType )
        if (eventType == TOUCH_EVENT_ENDED or eventType == TOUCH_EVENT_CANCELED) then
            print("Stop scroll")
            self.m_isScrolling = false
            self.m_scroollViewOffset = nil
        elseif(eventType == TOUCH_EVENT_BEGAN) then
            print("TouchBegin")
            self.m_scroollViewOffset = cc.p(sender:getInnerContainer():getPositionX(),sender:getInnerContainer():getPositionY())
        end
    end

    local function scrollEvent( sender, eventType )
        if (eventType == SCROLLVIEW_EVENT_SCROLLING ) then
            print("Start scroll")
            local curPos = cc.p(sender:getInnerContainer():getPositionX(),sender:getInnerContainer():getPositionY())
            local moveDis = cc.pGetDistance(self.m_scroollViewOffset,curPos)
             print(string.format("Scrolling dis = %f",moveDis))
            if(moveDis > 3) then
                self.m_isScrolling = true
            end
        end
    end


    local function selectItem( sender )
        local index = sender:getTag()
        -- if (data.tabIndex == 1) then
            self:selectActItem(index)
        -- else
        --     self:selectNotItem(index)
        -- end
    end

    local actList =
    {
        {name = "ui_huodong_tab", title = "签到奖励", tag = 1, timeLimit = false},
        {name = "ui_huodong_tab", title = "每日分享", tag = 2, timeLimit = false},
--        {name = "ui_huodong_left", title = "新手体验大礼", tag = 3, timeLimit = false},
--        {name = "ui_huodong_left", title = "盛世兑换", tag = 4, timeLimit = false},
    }
    local notList = {}    
    nodes.view = self.m_rootNode:getNodeByName("view")
    nodes.tabParent = self.m_rootNode:getNodeByName("buttonView")
    local ActivityIndex = 0
    local fristID = ACTIVITY_TYPE_DAILY_SHARE
    local tabTitle = ""
    
    local bview = ccui.ScrollView:create()
    bview:setDirection(kCCScrollViewDirectionVertical)
    bview:setAnchorPoint(cc.p(0, 1))
    bview:setPosition(cc.p(-BUTTON_VIEW_WIDTH/2, BUTTON_VIEW_HEIGHT/2))
    bview:setScrollBarPositionFromCornerForVertical(cc.p(5, 0))
    bview:setScrollBarEnabled(false)
    bview:setContentSize(cc.size(BUTTON_VIEW_WIDTH, BUTTON_VIEW_HEIGHT))
    bview:setBounceEnabled(true)

    nodes.tabPhone = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
    tabTitle = nodes.tabPhone:getNodeByName("ani"):getLabelByName("buttonName")    
    tabTitle:setString(getStringInLang("loc_connect_cellphone_title"))
    nodes.btnPhone = nodes.tabPhone:getNodeByName("btn")
    nodes.tabPhone:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
    
    bindPhoneOpen = CPPInterfaceManager:DataPlayer_IsOpenFeedBackEmailAndPhoneBind()
    nodes.tabPhone:setVisible(bindPhoneOpen)
    bview:addChild(nodes.tabPhone)
    if(bindPhoneOpen)then
        ActivityIndex = ActivityIndex + 1
    end

    setNEButtonCallBack(nodes.btnPhone, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    setNEButtonCallBack(nodes.btnPhone, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    setNEButtonCallBack(nodes.btnPhone, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)

    CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnPhone, false)

    nodes.tabSign = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
    tabTitle = nodes.tabSign:getNodeByName("ani"):getLabelByName("buttonName")    
    tabTitle:setString(getStringInLang("loc_keep_sign_title"))
    nodes.btnSign = nodes.tabSign:getNodeByName("btn")
    nodes.tabSign:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
    ActivityIndex = ActivityIndex + 1
    bview:addChild(nodes.tabSign)

    nodes.tabDailyShare = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
    tabTitle = nodes.tabDailyShare:getNodeByName("ani"):getLabelByName("buttonName")    
    tabTitle:setString(getStringInLang("loc_share_everyday_title_1"))
    nodes.btnDailyShare = nodes.tabDailyShare:getNodeByName("btn")
    nodes.tabDailyShare:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
    ActivityIndex = ActivityIndex + 1
    bview:addChild(nodes.tabDailyShare)


    local cumIsStart = DataChargeCum.IsVisible()
    nodes.tabCumCharge = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
    nodes.tabCumCharge:useSkin("ljczputong")
    if(cumIsStart==false) then
        nodes.tabCumCharge:useSkin("putong")
    end

    tabTitle = nodes.tabCumCharge:getNodeByName("ani"):getLabelByName("buttonName")    
    tabTitle:setString(getStringInLang("loc_activity_charge_limited_time_need_charged"))

    nodes.tabCumCharge:getNodeByName("ani/timeLimit"):setVisible(true)
    nodes.tabCumCharge:getLabelByName("ani/label"):setString(getStringInLang("loc_activity_slogan_limited_time"))
    labelTime = nodes.tabCumCharge:getNodeByName("ani"):getLabelByName("labelTime") 

    local strTime = CPPInterfaceManager:LString_formateRestTime(DataChargeCum.getChargeCumTime())
    labelTime:setString(strTime)
    labelTime:setVisible(true)
    nodes.btnCumCharge = nodes.tabCumCharge:getNodeByName("btn")
    nodes.tabCumCharge:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
    ActivityIndex = ActivityIndex + 1
    bview:addChild(nodes.tabCumCharge)

    cumBtn = nodes.tabCumCharge

    local EveryDayRechargeVisible = DataEveryDayRecharge.IsVisible()
    if(EveryDayRechargeVisible)then
        fristID = ACTIVITY_TYPE_EVERYDAY_RECHARGE
        nodes.tabEveryDayRecharge = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
        tabTitle = nodes.tabEveryDayRecharge:getNodeByName("ani"):getLabelByName("buttonName")
        tabTitle:setString(getStringInLang("loc_activity_continuous_recharge_label"))
        nodes.btnEveryDayRecharge = nodes.tabEveryDayRecharge:getNodeByName("btn")
        nodes.tabEveryDayRecharge:getNodeByName("ani/timeLimit"):setVisible(true)
        nodes.tabEveryDayRecharge:getLabelByName("ani/label"):setString(getStringInLang("loc_activity_slogan_hot"))
        nodes.tabEveryDayRecharge:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
        ActivityIndex = ActivityIndex + 1

        setNEButtonCallBack(nodes.btnEveryDayRecharge, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
        setNEButtonCallBack(nodes.btnEveryDayRecharge, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
        setNEButtonCallBack(nodes.btnEveryDayRecharge, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
        CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnEveryDayRecharge, false)
        bview:addChild(nodes.tabEveryDayRecharge)
    end

    local fundVisible = DataFund.IsVisible()
    if (fundVisible) then
        fristID = ACTIVITY_TYPE_FUND
        nodes.tabFund = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
        tabTitle = nodes.tabFund:getNodeByName("ani"):getLabelByName("buttonName")
        tabTitle:setString(getStringInLang("loc_growth_fund_title"))
        nodes.btnFund = nodes.tabFund:getNodeByName("btn")
        nodes.tabFund:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
        ActivityIndex = ActivityIndex + 1

        setNEButtonCallBack(nodes.btnFund, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
        setNEButtonCallBack(nodes.btnFund, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
        setNEButtonCallBack(nodes.btnFund, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
        CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnFund, false)
        bview:addChild(nodes.tabFund)
    end

    local timeLimitVisible = DataTimeLimit.IsVisible()
    if (timeLimitVisible) then
        fristID = ACTIVITY_TYPE_TIME_LIMIT
        nodes.tabTimeLimit = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
        tabTitle = nodes.tabTimeLimit:getNodeByName("ani"):getLabelByName("buttonName")
        tabTitle:setString(getStringInLang("loc_activity_charge_limited_time_table"))
        nodes.btnTimeLimit = nodes.tabTimeLimit:getNodeByName("btn")
        nodes.tabTimeLimit:getNodeByName("ani/timeLimit"):setVisible(true)
        nodes.tabTimeLimit:getLabelByName("ani/label"):setString(getStringInLang("loc_activity_slogan_limited_time"))
        nodes.tabTimeLimit:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
        ActivityIndex = ActivityIndex + 1

        setNEButtonCallBack(nodes.btnTimeLimit, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
        setNEButtonCallBack(nodes.btnTimeLimit, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
        setNEButtonCallBack(nodes.btnTimeLimit, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
        CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnTimeLimit, false)
        bview:addChild(nodes.tabTimeLimit)
    end

    local chargeSkinVisible = DataChargeSkin.IsVisible()
    if (chargeSkinVisible) then
        fristID = ACTIVITY_TYPE_CHARGE_SKIN
        nodes.tabChargeSkin = neanim.NEAnimNode:createNodeFromFile("ui_huodong_tab.ani")
        tabTitle = nodes.tabChargeSkin:getNodeByName("ani"):getLabelByName("buttonName")
        tabTitle:setString(getStringInLang("loc_activity_charge_limited_time_table"))
        nodes.btnChargeSkin = nodes.tabChargeSkin:getNodeByName("btn")
        nodes.tabChargeSkin:getNodeByName("ani/timeLimit"):setVisible(true)
        nodes.tabChargeSkin:getLabelByName("ani/label"):setString(getStringInLang("loc_activity_slogan_limited_time"))
        nodes.tabChargeSkin:setPosition(BUTTON_VIEW_WIDTH/2,BUTTON_VIEW_OFFSET_Y+BUTTON_HEIGHT*ActivityIndex)
        ActivityIndex = ActivityIndex + 1

        setNEButtonCallBack(nodes.btnChargeSkin, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
        setNEButtonCallBack(nodes.btnChargeSkin, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
        setNEButtonCallBack(nodes.btnChargeSkin, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
        CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnChargeSkin, false)
        bview:addChild(nodes.tabChargeSkin)
    end

    bview:setInnerContainerSize(cc.size(BUTTON_VIEW_WIDTH, ActivityIndex*BUTTON_HEIGHT+BUTTON_VIEW_OFFSET_Y/3))
    nodes.tabParent:addChild(bview, -1)
    
    bview:addTouchEventListener(scrollEnd)
    bview:addEventListener(scrollEvent)

    self:refreshSing()
    self:refreshWX()
    self:refreshTimeLimit()
    self:refreshEveryDay()
    self:refreshPhone()
    self:refreshCumCharge()

    setNEButtonCallBack(nodes.btnSign, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    setNEButtonCallBack(nodes.btnSign, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    setNEButtonCallBack(nodes.btnSign, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
    setNEButtonCallBack(nodes.btnDailyShare, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    setNEButtonCallBack(nodes.btnDailyShare, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    setNEButtonCallBack(nodes.btnDailyShare, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
    setNEButtonCallBack(nodes.btnCumCharge, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    setNEButtonCallBack(nodes.btnCumCharge, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    setNEButtonCallBack(nodes.btnCumCharge, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)

    CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnSign, false)
    CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnDailyShare, false)
    CPPInterfaceManager:NEButtonNode_SetSwallowTouches(nodes.btnCumCharge, false)

    nodes.scrBoardAct = createRightScrollView(nodes.view)
    -- nodes.scrBoardNot = createRightScrollView(view)

    setNEButtonCallBack(nodes.btnClose, NEBattleEvent.NEButtonEventTouchUpInside, closeSelf)
    setNEButtonCallBack(nodes.btnBGClose, NEBattleEvent.NEButtonEventTouchUpInside, closeSelf)
    -- setNEButtonCallBack(nodes.btnActivity, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    -- setNEButtonCallBack(nodes.btnNotice, NEBattleEvent.NEButtonEventTouchUpInside, onTabBtnTouchUpInside)
    -- setNEButtonCallBack(nodes.btnActivity, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    -- setNEButtonCallBack(nodes.btnNotice, NEBattleEvent.NEButtonEventTouchDown, onTabBtnTouchDown)
    -- setNEButtonCallBack(nodes.btnActivity, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)
    -- setNEButtonCallBack(nodes.btnNotice, NEBattleEvent.NEButtonEventTouchUpOutside, onTabBtnTouchUpOutside)

--    onTabBtnTouchUpInside(self.m_nodes.btnActivity)
    self:selectActItem(fristID)
end

function HuodongView:refreshSing()
    local nodes = self.m_nodes
    if (DataSign.getSupplyCount() ~= 0 or DataSign.canSignToday())then
        nodes.tabSign:getNodeByName("ani/notify"):setVisible(true)
    else
        nodes.tabSign:getNodeByName("ani/notify"):setVisible(false)
    end
end

function HuodongView:refreshWX()
    local nodes = self.m_nodes
    local state = CPPInterfaceManager:DataPlayer_ShareWXButtonState()
    if (state ~= 2) then
        nodes.tabDailyShare:getNodeByName("ani/notify"):setVisible(true)
    else
        nodes.tabDailyShare:getNodeByName("ani/notify"):setVisible(false)
    end
end

function HuodongView:refreshTimeLimit()
    local nodes = self.m_nodes
    local timeLimitVisible = DataTimeLimit.IsVisible()
    local timeLimitReward = DataTimeLimit.IsReward()
    if (timeLimitVisible) then
        if (timeLimitReward) then
            nodes.tabTimeLimit:getNodeByName("ani/notify"):setVisible(true)
        else
            nodes.tabTimeLimit:getNodeByName("ani/notify"):setVisible(false)
        end
    end
    local chargeSkinVisible = DataChargeSkin.IsVisible()
    local chargeSkinReward = DataChargeSkin.IsReward()
    if (chargeSkinVisible) then
        if (chargeSkinReward) then
            nodes.tabChargeSkin:getNodeByName("ani/notify"):setVisible(true)
        else
            nodes.tabChargeSkin:getNodeByName("ani/notify"):setVisible(false)
        end
    end

    local ChargeCumVisible = DataChargeCum.IsReward()
    if (ChargeCumVisible) then
        nodes.tabCumCharge:getNodeByName("ani/notify"):setVisible(true)
    else
        nodes.tabCumCharge:getNodeByName("ani/notify"):setVisible(false)
    end
end

function HuodongView:refreshEveryDay()
    local nodes = self.m_nodes
    local EveryDayRechargeVisible = DataEveryDayRecharge.IsVisible()
    local EveryDayRechargeReward = DataEveryDayRecharge.IsReward()
    if(EveryDayRechargeVisible)then
        if (EveryDayRechargeReward) then
            nodes.tabEveryDayRecharge:getNodeByName("ani/notify"):setVisible(true)
        else
            nodes.tabEveryDayRecharge:getNodeByName("ani/notify"):setVisible(false)
        end
    end

    local fundVisible = DataFund.IsVisible()
    local fundReward = DataFund.IsReward()
    if (fundVisible) then
        if (fundReward) then
            nodes.tabFund:getNodeByName("ani/notify"):setVisible(true)
        else
            nodes.tabFund:getNodeByName("ani/notify"):setVisible(false)
        end
    end
end

function HuodongView:refreshPhone()
    local nodes = self.m_nodes

    local BindPhoneVisible = DataBindPhone.IsVisible()
    if (BindPhoneVisible) then
        nodes.tabPhone:getNodeByName("ani/notify"):setVisible(true)
    else
        nodes.tabPhone:getNodeByName("ani/notify"):setVisible(false)
    end
end

function HuodongView:refreshCumCharge()
    local nodes = self.m_nodes
    local ChargeCumVisible = DataChargeCum.IsReward()
    if (ChargeCumVisible) then
        nodes.tabCumCharge:getNodeByName("ani/notify"):setVisible(true)
    else
        nodes.tabCumCharge:getNodeByName("ani/notify"):setVisible(false)
    end
end


function HuodongView:switchTab( button )
    if self.m_isScrolling then 
        print("IsScrolling cancell")
        return end
    local nodes = self.m_nodes
	local index = 0
   	if button == nodes.btnSign then
       index = ACTIVITY_TYPE_SIGN
   	elseif button == nodes.btnDailyShare then
       index = ACTIVITY_TYPE_DAILY_SHARE
	elseif button == nodes.btnTimeLimit then
        index = ACTIVITY_TYPE_TIME_LIMIT
    elseif button == nodes.btnEveryDayRecharge then
        index = ACTIVITY_TYPE_EVERYDAY_RECHARGE
    elseif button == nodes.btnPhone then
        index = ACTIVITY_TYPE_PHONE
    elseif button == nodes.btnChargeSkin then
        index = ACTIVITY_TYPE_CHARGE_SKIN
    elseif button == nodes.btnCumCharge then
        index = ACTIVITY_TYPE_CHARGE_CUM
    elseif button == nodes.btnFund then
        index = ACTIVITY_TYPE_FUND
   	end
    print(string.format("switch tab index %d", index))
    self:selectActItem(index)
end

local function setItemButtonSkin( btnData, state )
    if(btnData~=nil)then
        local ani = btnData:getNodeByName("ani")
        if (state == 1) then    --按钮高亮选中

            ani:getNodeByName("ImageHighlight"):setVisible(true)
            ani:useSkin("xuanzhong")
            if(cumBtn==btnData) then
                ani:useSkin("ljczxuanzhong")
                local cumIsStart = DataChargeCum.IsVisible()
                if(cumIsStart==false) then
                    ani:useSkin("putong")
                end
            end
        elseif (state == 2) then  --按钮可选中
            ani:getNodeByName("ImageHighlight"):setVisible(false)
            ani:useSkin("xuanzhong")
            if(cumBtn==btnData) then
                ani:useSkin("ljczxuanzhong")
                local cumIsStart = DataChargeCum.IsVisible()
                if(cumIsStart==false) then
                    ani:useSkin("putong")
                end
            end
        else    --按钮不可选中
            ani:getNodeByName("ImageHighlight"):setVisible(false)
            ani:useSkin("putong")
            if(cumBtn==btnData) then
                ani:useSkin("ljczputong")
                local cumIsStart = DataChargeCum.IsVisible()
                if(cumIsStart==false) then
                    ani:useSkin("putong")
                end
            end
        end
    end
end

function HuodongView:selectActItem( index )
    local nodes = self.m_nodes
    if (self.m_data.actIndex ~= index) then
    	if (index == ACTIVITY_TYPE_SIGN) then
            setItemButtonSkin(nodes.tabSign, 1)    	
            setItemButtonSkin(nodes.tabDailyShare, 2)   
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabPhone, 2)
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            setItemButtonSkin(nodes.tabFund, 2)
			insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "SignView") 	             	
    	elseif(index == ACTIVITY_TYPE_DAILY_SHARE) then
            setItemButtonSkin(nodes.tabDailyShare, 1)
            setItemButtonSkin(nodes.tabSign, 2)    	
            setItemButtonSkin(nodes.tabTimeLimit, 2)	
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabPhone, 2)  
            setItemButtonSkin(nodes.tabChargeSkin, 2)   
            setItemButtonSkin(nodes.tabCumCharge, 2)     
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "ActivityDailyShare")
        elseif(index == ACTIVITY_TYPE_TIME_LIMIT) then
            setItemButtonSkin(nodes.tabTimeLimit, 1)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)   
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabPhone, 2) 
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "TimeLimit")
        elseif(index == ACTIVITY_TYPE_EVERYDAY_RECHARGE) then
            setItemButtonSkin(nodes.tabEveryDayRecharge, 1)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)    
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabPhone, 2)
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "EveryDayRecharge")
        elseif(index == ACTIVITY_TYPE_PHONE) then
            setItemButtonSkin(nodes.tabPhone, 1)
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)    
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "BindPhone")
        elseif(index == ACTIVITY_TYPE_CHARGE_SKIN) then
            setItemButtonSkin(nodes.tabChargeSkin, 1)
            setItemButtonSkin(nodes.tabPhone, 2)
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)    
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "ChargeSkin")
        elseif(index == ACTIVITY_TYPE_FUND) then
            setItemButtonSkin(nodes.tabFund, 1)
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabPhone, 2)
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)    
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabCumCharge, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "ChargeFund")
        elseif(index == ACTIVITY_TYPE_CHARGE_CUM) then
            local cumIsStart = DataChargeCum.IsVisible()
            if(cumIsStart==false) then
                CPPInterfaceManager:UI_ShowWarningMessage("loc_activity_cumulative_recharge_closed",0)
                return
            end
            setItemButtonSkin(nodes.tabCumCharge, 1)
            setItemButtonSkin(nodes.tabChargeSkin, 2)
            setItemButtonSkin(nodes.tabPhone, 2)
            setItemButtonSkin(nodes.tabEveryDayRecharge, 2)
            setItemButtonSkin(nodes.tabSign, 2)      
            setItemButtonSkin(nodes.tabDailyShare, 2)    
            setItemButtonSkin(nodes.tabTimeLimit, 2)
            setItemButtonSkin(nodes.tabFund, 2)
            insertWithoutScrollview(self, self.m_nodes.scrBoardAct, nodes.view, "ChargeCum")
    	end

        self.m_data.actIndex = index
    end
end
 
 
return HuodongView
