--module(...,package.seeall)
local MainInterface = class("MainInterface", require("BaseView"))

local _super = MainInterface.super

local NEButtonData = AppData.NEButtonData

local function createActive()
    local active = {}
    local activeNode = neanim.NEAnimNode:createNodeFromFile("ui_baseland_right_panel.ani")
    activeNode:setPosition(cc.p( winSizeHalf.width - 65, winSizeHalf.height - 80))
    active.root = activeNode
    active.charge = activeNode:getNodeByName("active")
    active.btnCharge = activeNode:getNodeByName("active_button")
    active.labCharge = active.charge:getLabelByName("label")
    active.labCharge:setString(getStringInLang("loc_first_charge"))
    return active
end

local function createRetrunDiamond()
    local diamond = {}
    local rdNode = neanim.NEAnimNode:createNodeFromFile("ui_baseland_right_panel.ani")
    rdNode:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 140))
    diamond.root = rdNode
    diamond.open = rdNode:getNodeByName("active")
    diamond.open:useSkin("F19")
    diamond.btnOpen = rdNode:getNodeByName("active_button")
    diamond.labOpen = diamond.open:getLabelByName("label")
    diamond.labOpen:setString(getStringInLang("loc_test_charge_return_button"))
    return diamond
end

local function createMercenaryPackage()
    local MercenaryPackage = {}
    local rdNode = neanim.NEAnimNode:createNodeFromFile("ui_baseland_right_panel.ani")
    rdNode:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 80))
    MercenaryPackage.root = rdNode
    MercenaryPackage.open = rdNode:getNodeByName("active")
    MercenaryPackage.open:useSkin("F20")
    MercenaryPackage.btnOpen = rdNode:getNodeByName("active_button")
    MercenaryPackage.labOpen = MercenaryPackage.open:getLabelByName("label")
    MercenaryPackage.labOpen:setString(getStringInLang("loc_mercenary_gift_pack"))
    return MercenaryPackage
end

function MainInterface:ctor()
	_super.ctor(self, "")
    print("MainInterface:ctor")

    messageManager:register(EVENT.MODIFY_PLAYER_DATA, self, self.refresh)
    messageManager:register(EVENT.MODIFY_PLAYER_CHARGE, self, self.refresh)
    messageManager:register(MESSAGE.SC_CHARGE, self, self.refresh)
    messageManager:register(MESSAGE.SC_CHARGE_TEST, self, self.refresh)
    messageManager:register(EVENT.SC_CHARGE_VISIBLEFALSE, self, self.setChargeVisibleFalse)
    messageManager:register(EVENT.SC_CHARGE_VISIBLETRUE, self, self.setChargeVisibleTrue)

    self:initView()
end

function MainInterface:dtor()
    messageManager:unregister(EVENT.MODIFY_PLAYER_DATA, self, self.refresh)
    messageManager:unregister(EVENT.MODIFY_PLAYER_CHARGE, self, self.refresh)
    messageManager:unregister(MESSAGE.SC_CHARGE, self, self.refresh)
    messageManager:unregister(MESSAGE.SC_CHARGE_TEST, self, self.refresh)
    messageManager:unregister(EVENT.SC_CHARGE_VISIBLEFALSE, self, self.setChargeVisibleFalse)
    messageManager:unregister(EVENT.SC_CHARGE_VISIBLETRUE, self, self.setChargeVisibleTrue)

    _super.dtor(self)
    print("MainInterface:dtor")
end

function MainInterface:initView()
    local nodes = self.m_nodes
    local data = self.m_data
    local lcNodes = self.m_leftCenter

    if self.m_rootNode then
    	self.m_rootNode:setPosition(cc.p(winSizeHalf.width, winSizeHalf.height))
    end

    self.m_active = createActive()
    self.m_rootNode:addChild(self.m_active.root)

    local function recoverIcon()
        self.m_active.charge:playAnimation("pingshi")
    end

    local function activeTouchInside( sender )
        if (sender == self.m_active.btnCharge) then
            self:openWindow("FirstChargeView")
            performWithDelay(self.m_rootNode, recoverIcon, 0.2)
        end
    end

    local function activeTouchOutside( sender )
        if (sender == self.m_active.btnCharge) then
            performWithDelay(self.m_rootNode, recoverIcon, 0.2)
        end
    end

    local function diamondTouchInside( sender )
        if (sender == self.m_diamond.btnOpen) then
            self:openWindow("ReturnDiamond")
        end
    end

    local function mercenaryPackageTouchInside( sender )
        if (sender == self.m_mercenaryPackage.btnOpen) then
            self:openWindow("MercenaryPackage")
        end
    end

    local function leftCenterTouchEvent( sender )
        if (sender == self.m_leftCenter.btnAchieve) then
            self:openWindow("AchievementView", 1)
        end
    end

    if (DataRetDiamond.canAccept()) then
        self.m_diamond = createRetrunDiamond()
        self.m_rootNode:addChild(self.m_diamond.root)
        setNEButtonCallBack(self.m_diamond.btnOpen, NEBattleEvent.NEButtonEventTouchUpInside, diamondTouchInside)
        messageManager:sendS(MESSAGE.CS_RETURN_DIAMOND, {})
    end

    self.m_mercenaryPackage = createMercenaryPackage()
    self.m_rootNode:addChild(self.m_mercenaryPackage.root)
    setNEButtonCallBack(self.m_mercenaryPackage.btnOpen, NEBattleEvent.NEButtonEventTouchUpInside, mercenaryPackageTouchInside)
    

    setNEButtonCallBack(self.m_active.btnCharge, NEBattleEvent.NEButtonEventTouchUpInside, activeTouchInside)
    setNEButtonCallBack(self.m_active.btnCharge, NEBattleEvent.NEButtonEventTouchUpOutside, activeTouchOutside)


    self:eventModify()
end


function MainInterface:eventModify( messageType )
    local isInGuide = CPPInterfaceManager:DataPlayer_IsInGuideStatus()
    --local firstCharge = not CPPInterfaceManager:DataPlayer_IsRecharge()
    --self.m_active.charge:setVisible(not isInGuide and firstCharge)
    self.m_active.charge:setVisible(false)
    self.m_mercenaryPackage.open:setVisible(false)
    -- if (not firstCharge) then
    --     self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 80))
    -- else
    --     self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 140))
    -- end
end

function MainInterface:refresh( messageType, data )
    local isInGuide = CPPInterfaceManager:DataPlayer_IsInGuideStatus()
    --local firstCharge = not CPPInterfaceManager:DataPlayer_IsRecharge()
    --self.m_active.charge:setVisible(not isInGuide and firstCharge)
    self.m_active.charge:setVisible(false)
    self.m_mercenaryPackage.open:setVisible(not isInGuide)
    -- if (not firstCharge) then
    --     self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 80))
    -- else
    --     self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 140))
    -- end
end

function MainInterface:setChargeVisibleFalse( messageType )
    --self.m_active.charge:setVisible(false)
    --self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 80))
end

function MainInterface:setChargeVisibleTrue( messageType )
    --self.m_active.charge:setVisible(true)
    --self.m_mercenaryPackage.root:setPosition(cc.p(winSizeHalf.width - 65, winSizeHalf.height - 140))
end

return MainInterface
