NEBattleEvent =
{ 
    NEButtonEventNone                = 0,
    NEButtonEventTouchDown           = 2 ^ 0,    -- A touch-down event in the control.
    NEButtonEventTouchDragInside     = 2 ^ 1,    -- An event where a finger is dragged inside the bounds of the control.
    NEButtonEventTouchDragOutside    = 2 ^ 2,    -- An event where a finger is dragged just outside the bounds of the control.
    NEButtonEventTouchDragEnter      = 2 ^ 3,    -- An event where a finger is dragged into the bounds of the control.
    NEButtonEventTouchDragExit       = 2 ^ 4,   -- An event where a finger is dragged from within a control to outside its bounds.
    NEButtonEventTouchUpInside       = 2 ^ 5,    -- A touch-up event in the control where the finger is inside the bounds of the control.
    NEButtonEventTouchUpOutside      = 2 ^ 6,    -- A touch-up event in the control where the finger is outside the bounds of the control.
    NEButtonEventTouchCancel         = 2 ^ 7,    -- A system event canceling the current touches for the control.
    NEButtonEventAnimPushDone        = 2 ^ 8,
    NEButtonEventAnimReleaseDone     = 2 ^ 9,
    NEButtonEventClick               = 2 ^ 10,
}

local NEButtonData = class("NEButtonData")

-- Node m_root
-- Node m_image
-- Node m_target
-- Table m_customData

function NEButtonData:ctor( button, imageName, targetName, tag )
    self.m_root = button
    self.m_image = button:getNodeByName(imageName)
    self.m_target = button:getNodeByName(targetName)
    self.m_target:setTag(tag)
end

function NEButtonData:setCallback( ... )
    local params = { ... }
    for i, param in ipairs(params) do
        setNEButtonCallBack(self.m_target, param.type, param.func)
    end
end

function NEButtonData:setCustomData( data )
    self.m_customData = data
end

function NEButtonData:setPosition( x, y )
    self.m_root:setPosition(cc.p(x, y))
end

function NEButtonData:setSkin( nodeName, skinName )
    if (nodeName ~= "") then
        self.m_root:getNodeByName(nodeName):useSkin(skinName)
    else
        self.m_root:useSkin(skinName)
    end
end

function NEButtonData:setSwallowTouches( swallow )
    self.m_root:setSwallowTouches(swallow)
end

function NEButtonData:getTag()
    return self.m_target:getTag()
end

function NEButtonData:getCustomData( key )
    if (key) then
        return self.m_customData[key]
    else
        return self.m_customData
    end
end

function NEButtonData:getSize()
    local size = self.m_image:getContentSize()
    size.width = size.width * self.m_image:getScaleX()
    size.height = size.height * self.m_image:getScaleY()
    return size
end

function NEButtonData:getNode( name )
    return self.m_root:getNodeByName(name)
end

function NEButtonData:getLabel( name )
    return self.m_root:getLabelByName(name)
end

function NEButtonData:setSwallowTouches( isSwallow )
    CPPInterfaceManager:NEButtonNode_SetSwallowTouches(self.m_target,isSwallow)
end

function NEButtonData:setTouchEnabled( isEnabled )
    CPPInterfaceManager:NEButtonNode_SetTouchEnabled(self.m_target,isEnabled)
end

return NEButtonData
