local ReturnDiamond = class("ReturnDiamond", require("BaseView"))

local _super = ReturnDiamond.super

local SHOP_ITEM_TOTAL = 7

local BUY_ITEM_DISTANCE_Y = 13

local SHOP_ITEM_NAMES = 
{
    "loc_shop_item_name_dimond_handful",
    "loc_shop_item_name_dimond_pile",
    "loc_shop_item_name_dimond_pouch",
    "loc_shop_item_name_dimond_bag",
    "loc_shop_item_name_dimond_box",
    "loc_shop_item_name_dimond_crate",
}

local SHOP_ITEM_DIAMOND = 
{
    "loc_shop_item_name_dimond_handful",
    "loc_shop_item_name_dimond_pile",
    "loc_shop_item_name_dimond_pouch",
    "loc_shop_item_name_dimond_bag",
    "loc_shop_item_name_dimond_box",
    "loc_shop_item_name_dimond_crate",
}

function ReturnDiamond:ctor(parent)
	_super.ctor(self, "ui_chongzhibuchang", true)
    print("ReturnDiamond:ctor")
    messageManager:register(MESSAGE.SC_RETURN_DIAMOND, self, self.refresh)
    messageManager:register(MESSAGE.SC_ACCEPT_DIAMOND, self, self.acceptDiamond)
    self:setName("ReturnDiamond")
    self:setNeedMask(parent, true)
    self:createBackground(VIEW_BACKGROUND_NO_COLOR, true)
    self:initView()
end

function ReturnDiamond:dtor()
    self.m_itemList = nil
    self.m_isScrolling = nil
    messageManager:unregister(MESSAGE.SC_RETURN_DIAMOND, self, self.refresh)
    messageManager:unregister(MESSAGE.SC_ACCEPT_DIAMOND, self, self.acceptDiamond)
    _super.dtor(self)
    print("ReturnDiamond:dtor")
end

function ReturnDiamond:initView()
    local nodes = self.m_nodes
    local data = self.m_data

    if self.m_rootNode then
    	self.m_rootNode:setPosition(cc.p(winSizeHalf.width, winSizeHalf.height))
    end

    nodes.btnClose = self.m_rootNode:getNodeByName("closeButton")
    nodes.animAccept = self.m_rootNode:getNodeByName("acceptAnim")
    nodes.btnAccept = self.m_rootNode:getNodeByName("acceptButton")
    nodes.labTitle = self.m_rootNode:getLabelByName("title")
    local animContent = self.m_rootNode:getNodeByName("animContent")

    nodes.nodeContain = animContent:getNodeByName("weekCardNode")  --有周卡的显示节点
    nodes.labWeekTitle = animContent:getLabelByName("weekCardTitle")
    nodes.labWeekContent = animContent:getLabelByName("weekCardContent")
    nodes.labMonthTitle = animContent:getLabelByName("monthCardTitle")
    nodes.labMonthContent = animContent:getLabelByName("monthCardContent")

    nodes.labNoWeekCard = animContent:getLabelByName("noWeekCard") -- 没有周卡的显示文字

    nodes.labDiamondReturn = animContent:getLabelByName("diamondReturn")
    nodes.labBuyTotal = animContent:getLabelByName("buyTotal")
    nodes.labAllBuy = animContent:getLabelByName("allBuy")
    nodes.labAllReturn = animContent:getLabelByName("allReturn")
    nodes.imgMonthIcon = animContent:getNodeByName("monthIcon")
    nodes.imgDiamondIcon = animContent:getNodeByName("diamondIcon")
    nodes.nodeItem = animContent:getNodeByName("nodeItem")

    nodes.labTitle:setString(getStringInLang("loc_test_charge_return"))
    nodes.animAccept:getLabelByName("buttonLabel"):setString(getStringInLang("loc_mail_claim_button"))
    nodes.labMonthTitle:setString(getStringInLang("loc_test_return"))
    nodes.labDiamondReturn:setString(getStringInLang("loc_test_return_dimond"))
    nodes.labBuyTotal:setString(getStringInLang("loc_test_return_total"))
    nodes.labWeekContent:setString(getStringInLang("loc_test_week_card") .. " x1")
    nodes.labMonthContent:setString(getStringInLang("loc_test_month_card") .. " x1价值¥128")

    local function closeSelf( sender )
        if (sender == nodes.btnClose) then
            self:closeWindow("ReturnDiamond")
        end
    end

    local function acceptDiamondEvent( sender )
        if (not DataRetDiamond.isAccepted()) then
            messageManager:sendS(MESSAGE.CS_ACCEPT_DIAMOND, {})
        end
    end

    setNEButtonCallBack(nodes.btnClose, NEBattleEvent.NEButtonEventTouchUpInside, closeSelf)
    setNEButtonCallBack(nodes.btnAccept, NEBattleEvent.NEButtonEventTouchUpInside, acceptDiamondEvent)

    self:refresh()
end

local function createItemCell( id, count, diamond )
    local node = neanim.NEAnimNode:createNodeFromFile("ui_buchang_zuanshishuliang.ani")
    node:getLabelByName("buy"):setString(getStringInLang(SHOP_ITEM_NAMES[id]) .. " x" .. count)
    node:getLabelByName("return"):setString(tostring(diamond))
    return node
end

function ReturnDiamond:refresh()
    local isBoughtWeekCard = DataRetDiamond.isBoughtWeekCard()
    local firstNode = self.m_nodes.nodeItem
    firstNode:removeAllChildren()

    self.m_nodes.nodeContain:setVisible(false)
    self.m_nodes.labNoWeekCard:setVisible(false)
        
        
    if (isBoughtWeekCard) then
        self.m_nodes.nodeContain:setVisible(true)
        self.m_nodes.labWeekTitle:setString(getStringInLang("loc_test_buy"))
        local weekCardNum = DataRetDiamond.getWeekCardNum()
        self.m_nodes.labWeekContent:setString(getStringInLang("loc_test_week_card") .. " x"..weekCardNum)
        self.m_nodes.labMonthContent:setString(getStringInLang("loc_test_month_card") .. " x" .. weekCardNum .. getStringInLang("loc_charge_return_price") .. DataRetDiamond.getWeekCardPrice() )
    else
        self.m_nodes.labNoWeekCard:setVisible(true)
        self.m_nodes.labNoWeekCard:setString(getStringInLang("loc_test_no_week_card"))
    end
    
    local posY = 0
    for i = 1, SHOP_ITEM_TOTAL do
        local item = DataRetDiamond.getBoughtItem(i)
        if (item and item.buy > 0) then
            local cell = createItemCell(i, item.buy, item.diamond)
            cell:setPositionY(posY)
            firstNode:addChild(cell)
            posY = posY - BUY_ITEM_DISTANCE_Y
        end
    end
    self.m_nodes.labAllBuy:setString("")--tostring(DataRetDiamond.getBoughtDiamond()))
    self.m_nodes.labAllReturn:setString(tostring(DataRetDiamond.getReturnDiamond()))

    if (DataRetDiamond.isAccepted()) then
        self.m_nodes.animAccept:useSkin("F62")
        -- self.m_nodes.btnAccept:setEnabled(false)
    end
end

function ReturnDiamond:acceptDiamond()
    if (DataRetDiamond.isAccepted()) then
        local diamondReturn = DataRetDiamond.getReturnDiamond()
        CPPInterfaceManager:DataPlayer_AddDiamond(diamondReturn)
        CPPInterfaceManager:UIEffect_FlyResourceIcon(self.m_nodes.imgDiamondIcon, 0, 0, 11, diamondReturn)
        if (DataRetDiamond.isBoughtWeekCard()) then
            local cgAnimNode = neanim.NEAnimNode:createNodeFromFile("zc_shopchongzhichenggong.ani")
            local function closeAnim()
                cgAnimNode:playAnimation("xiaoshi")
                cgAnimNode:getNodeByName("mask2"):setVisible(false)
            end
            cgAnimNode:setPosition(cc.p(20, 60))
            cgAnimNode:setScale(0.4)
            cgAnimNode:playAnimation("chuxian")
            cgAnimNode:getNodeByName("mask"):setVisible(false)
            self.m_rootNode:addChild(cgAnimNode)
            performWithDelay(self.m_rootNode, closeAnim, 3)
        end
        self.m_nodes.animAccept:useSkin("F62")
    end
end

return ReturnDiamond
