SCROLLVIEW_DIRECTION_VER    = 1
SCROLLVIEW_DIRECTION_HOR    = 2

ScrollViewBar = class("ScrollViewBar")

-- m_rootNode
-- m_bottom
-- m_bar
-- m_direction
-- m_target
-- m_length
-- m_scrollListener

local function resetBarLength( length, direction, bottom, bar, sv )
    if (bottom) then
        if (direction == SCROLLVIEW_DIRECTION_VER) then
            length.max = bottom:getContentSize().height * bottom:getScaleY() - 4
            length.orig = bottom:getPositionY() + length.max / 2
        else
            length.max = bottom:getContentSize().width * bottom:getScaleX() - 4
            length.orig = bottom:getPositionX() - length.max / 2
        end
    end

    if (bar and sv) then
        if (direction == SCROLLVIEW_DIRECTION_VER) then
            length.cur = sv:getContentSize().height / sv:getInnerContainerSize().height * length.max
            length.scale = length.cur / bar:getContentSize().height * bar:getScaleY()
            bar:setScaleY(length.scale)
        else
            length.cur = sv:getContentSize().width / sv:getInnerContainerSize().width * length.max
            length.scale = length.cur / bar:getContentSize().width * bar:getScaleX()
            bar:setScaleX(length.scale)
        end
    else
        length.cur = 0
    end
end

local function getScrollDistance( direction, sv )
    if (sv) then
        if (direction == SCROLLVIEW_DIRECTION_VER) then
            return (sv:getInnerContainerSize().height - sv:getContentSize().height)
        else
            return (sv:getInnerContainerSize().width - sv:getContentSize().width)
        end
    end
    return 0
end

local function setBarScaleX( bar, length, posX )
    bar:setScaleX(math.max(0.05, (length.cur - posX) / length.cur * length.scale))
end

local function setBarScaleY( bar, length, posY )
    bar:setScaleY(math.max(0.05, (length.cur - posY) / length.cur * length.scale))
end

function ScrollViewBar:ctor( nodeProgress, nodeBottom, nodeBar )
    self.m_rootNode = nodeProgress
    self.m_bottom = nodeBottom
    self.m_bar = nodeBar
    self.m_direction = SCROLLVIEW_DIRECTION_HOR
    self.m_length = {}
    self.m_scrollDistance = 0

    local function svEvent()
        if (not self.m_target) then return end
        self:resetBarPos()
    end

    schedule(self.m_rootNode, svEvent, 0)
end

function ScrollViewBar:dtor()
    self.m_rootNode = nil
    self.m_bottom = nil
    self.m_bar = nil
    self.m_target = nil
    self.m_direction = nil
    self.m_length = nil
    self.m_scrollDistance = nil
    self.m_scrollListener = nil
end

-- 设置滚动方向
function ScrollViewBar:setDirection( dir )
    self.m_direction = dir
    resetBarLength(self.m_length, dir, self.m_bottom, self.m_bar)
end

-- 关联Scrollview
function ScrollViewBar:attachView( scrollview )
    self.m_target = scrollview
    self.m_scrollDistance = getScrollDistance(self.m_direction, scrollview)
    resetBarLength(self.m_length, dir, nil, self.m_bar, scrollview)
    self.m_rootNode:setVisible(self.m_scrollDistance > 0)
end

-- 设置滑块位置
function ScrollViewBar:resetBarPos()
    if (self.m_scrollDistance == 0) then return end

    local pos = self.m_target:getInnerContainerPosition()
    local max = self.m_length.max - self.m_length.cur
    if (self.m_direction == SCROLLVIEW_DIRECTION_VER) then
        if (pos.y < 0) then
            setBarScaleY(self.m_bar, self.m_length, pos.y)
            local posY = math.between(pos.y / self.m_scrollDistance * max, 0, max)
            self.m_bar:setPositionY(self.m_length.orig - posY)
        elseif (pos.y > self.m_scrollDistance) then
            setBarScaleY(self.m_bar, self.m_length, -self.m_scrollDistance - pos.y)
            self.m_bar:setPositionY(self.m_length.orig + self.m_length.max - self.m_bar:getContentSize().width * self.m_bar:getScaleY())
        else
            local posY = math.between(pos.y / self.m_scrollDistance * max, 0, max)
            self.m_bar:setPositionY(self.m_length.orig - posY)
        end
    else
        if (pos.x > 0) then
            setBarScaleX(self.m_bar, self.m_length, pos.x)
            local posX = math.between(-pos.x / self.m_scrollDistance * max, 0, max)
            self.m_bar:setPositionX(self.m_length.orig + posX)
        elseif (pos.x < -self.m_scrollDistance) then
            setBarScaleX(self.m_bar, self.m_length, -self.m_scrollDistance - pos.x)
            self.m_bar:setPositionX(self.m_length.orig + self.m_length.max - self.m_bar:getContentSize().width * self.m_bar:getScaleX())
        else
            local posX = math.between(-pos.x / self.m_scrollDistance * max, 0, max)
            self.m_bar:setPositionX(self.m_length.orig + posX)
        end
    end
end

function ScrollViewBar:setScrollListener(func)
    self.m_scrollListener = func
end